@@ -142,11 +142,11 @@ static char* optionsHelpArray[] = {
 "                                        instead of 6:37)",
 "    -F, --daf-yomi                     Output the Daf Yomi for the entire",
 "                                        date range",
-"    -g, --iso-8601                     Ouput ISO 8601 dates -- YYYY-MM-DD",
+"    -g, --iso-8601                     Output ISO 8601 dates -- YYYY-MM-DD",
 "                                            this overrides -y", 
 "    -h, --no-holidays                  Suppress default holidays",
 "    -i, --israeli                      Israeli holiday and sedra schedule",
-"    --lang LANG                        Use LANG titles (he, ru, or pl)",
+"    --lang LANG                        Use LANG titles (" HEBCAL_LANG_LIST ")",
 "    -M, --molad                        Print the molad on Shabbat Mevorchim",
 "    --no-modern                        Suppress modern holidays",
 "    -o, --omer                         Add days of the Omer",
